@@ -3,11 +3,14 @@
 use strict;
 use warnings;
 
+use Data::Icon;
 use Data::InfoBox::Item;
 use Data::Text::Simple;
 
 my $obj = Data::InfoBox::Item->new(
-        'icon_url' => 'https://example.com/foo.png',
+        'icon' => Data::Icon->new(
+                'url' => 'https://example.com/foo.png',
+        ),
         'text' => Data::Text::Simple->new(
                 'text' => 'Funny item'
         ),
@@ -15,7 +18,7 @@ my $obj = Data::InfoBox::Item->new(
 );
 
 # Print out.
-print "Icon URL: ".$obj->icon_url."\n";
+print "Icon URL: ".$obj->icon->url."\n";
 print "Text: ".$obj->text->text."\n";
 print "URI: ".$obj->uri."\n";
 
